Documentation
¶
Overview ¶
Copyright (c) 2021-2024 - for information on the respective copyright owner see the NOTICE file and/or the repository https://github.com/carbynestack/ephemeral.
SPDX-License-Identifier: Apache-2.0
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AbstractClient ¶
type AbstractClient interface {
}
AbstractClient is an interface for object storage client.
type Client ¶
Client is a client for Amphora.
func (*Client) CreateSecretShare ¶
func (c *Client) CreateSecretShare(os *SecretShare) error
CreateSecretShare creates a new secret share by sending a POST request against Amphora.
func (*Client) GetSecretShare ¶
func (c *Client) GetSecretShare(id string, programIdentifier string) (SecretShare, error)
GetSecretShare creates a new secret share by sending a POST request against Amphora.
type SecretShare ¶
type SecretShare struct {
}
SecretShare is a secret-shared value stored in Amphora.
Click to show internal directories.
Click to hide internal directories.