Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MpcV1alpha1Client ¶
type MpcV1alpha1Client struct {
// contains filtered or unexported fields
}
MpcV1alpha1Client is used to interact with features provided by the mpc.bosch.com group.
func New ¶
func New(c rest.Interface) *MpcV1alpha1Client
New creates a new MpcV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*MpcV1alpha1Client, error)
NewForConfig creates a new MpcV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *MpcV1alpha1Client
NewForConfigOrDie creates a new MpcV1alpha1Client for the given config and panics if there is an error in the config.
func NewWithoutConfigOrDie ¶
func NewWithoutConfigOrDie() *MpcV1alpha1Client
This is a manually implemented hack, needs to be removed once the network-conftroller is published and could be vendored.
func (*MpcV1alpha1Client) Networks ¶
func (c *MpcV1alpha1Client) Networks(namespace string) NetworkInterface
func (*MpcV1alpha1Client) RESTClient ¶
func (c *MpcV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type MpcV1alpha1Interface ¶
type MpcV1alpha1Interface interface {
RESTClient() rest.Interface
NetworksGetter
}
type NetworkExpansion ¶
type NetworkExpansion interface{}
type NetworkInterface ¶
type NetworkInterface interface {
Create(*v1alpha1.Network) (*v1alpha1.Network, error)
Update(*v1alpha1.Network) (*v1alpha1.Network, error)
UpdateStatus(*v1alpha1.Network) (*v1alpha1.Network, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Network, error)
List(opts v1.ListOptions) (*v1alpha1.NetworkList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Network, err error)
NetworkExpansion
}
NetworkInterface has methods to work with Network resources.
type NetworksGetter ¶
type NetworksGetter interface {
Networks(namespace string) NetworkInterface
}
NetworksGetter has a method to return a NetworkInterface. A group's client should implement this interface.