Documentation
¶
Index ¶
- func NewFilteredNetworkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewNetworkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type Interface
- type NetworkInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredNetworkInformer ¶
func NewFilteredNetworkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredNetworkInformer constructs a new informer for Network type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewNetworkInformer ¶
func NewNetworkInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewNetworkInformer constructs a new informer for Network type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// Networks returns a NetworkInformer.
Networks() NetworkInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type NetworkInformer ¶
type NetworkInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.NetworkLister
}
NetworkInformer provides access to a shared informer and lister for Networks.